@@ -109,6 +109,8 @@ class Optimizer:
         self.grad_min = self.grad
 
         self.hessian_update: HessianApproximation = hessian_update
+        self.iterations_since_tr_update: int = 0
+        self.hybrid_switch: bool = False
 
         self.starttime: float = np.nan
         self.iteration: int = 0
@@ -120,11 +122,12 @@ class Optimizer:
     def _reset(self):
         self.starttime = time.time()
         self.iteration = 0
-        self.converged: bool = False
-        self.delta: float = self.get_option(Options.DELTA_INIT)
-        self.delta_iter: float = self.delta
+        self.converged = False
+        self.delta = self.get_option(Options.DELTA_INIT)
+        self.delta_iter = self.delta
         self.fval_min = np.inf
         self.logger = create_logger(self.verbose)
+        self.hybrid_switch = False
 
     def minimize(self, x0: np.ndarray):
         """
@@ -236,6 +239,9 @@ class Optimizer:
                     subspace_dim=self.get_option(Options.SUBSPACE_DIM),
                     stepback_strategy=self.get_option(Options.STEPBACK_STRAT),
                     refine_stepback=self.get_option(Options.REFINE_STEPBACK),
+                    use_scaled_gradient=self.get_option(
+                        Options.SCALED_GRADIENT
+                    ),
                     logger=self.logger
                 )
 
@@ -312,9 +318,14 @@ class Optimizer:
 
         if self.hessian_update is None or \
                 (isinstance(self.hessian_update, HybridUpdate) and
-                 self.iteration < self.hessian_update.switch_iteration):
+                 (self.iterations_since_tr_update <
+                  self.hessian_update.switch_iteration and not
+                  self.hybrid_switch)):
             self.hess = hess_new
         else:
+            if not self.hybrid_switch:
+                self.logger.info('Hybrid switchpoint reached.')
+            self.hybrid_switch = True
             self.hess = self.hessian_update.get_mat()
         self.check_in_bounds(x_new)
         self.fval = fval_new
@@ -345,12 +356,14 @@ class Optimizer:
         """
         stepsx = step.ss + step.ss0
         nsx = norm(stepsx)
+        self.iterations_since_tr_update += 1
         if not np.isfinite(fval):
             self.tr_ratio = 0
             self.delta = np.nanmin([
                 self.delta * self.get_option(Options.GAMMA1),
                 nsx / 4
             ])
+            self.iterations_since_tr_update = 0
             return False
         else:
             qpval = 0.5 * stepsx.dot(dv * np.abs(grad) * stepsx)
@@ -363,6 +376,7 @@ class Optimizer:
                     and not interior_solution and step.qpval <= 0:
                 # increase radius
                 self.delta = self.get_option(Options.GAMMA2) * self.delta
+                self.iterations_since_tr_update = 0
             elif self.tr_ratio <= self.get_option(Options.MU) or \
                     step.qpval > 0:
                 # decrease radius
@@ -370,6 +384,7 @@ class Optimizer:
                     self.delta * self.get_option(Options.GAMMA1),
                     nsx / 4
                 ])
+                self.iterations_since_tr_update = 0
             return self.tr_ratio > 0.0 and step.qpval <= 0
 
     def check_convergence(self, step: Step, fval: float,
@@ -424,11 +439,12 @@ class Optimizer:
             )
             converged = True
 
-        elif gnorm <= grtol * self.fval:
+        elif gnorm <= grtol * np.abs(self.fval):
             self.exitflag = ExitFlag.GTOL
             self.logger.warning(
                 'Stopping as gradient norm satisfies relative convergence '
-                f'criteria: {gnorm:.2E} < {grtol:.2E} * {self.fval:.2E}'
+                f'criteria: {gnorm:.2E} < {grtol:.2E} * '
+                f'{np.abs(self.fval):.2E}'
             )
             converged = True
 
